@@ -16,11 +16,12 @@
 #include <KLocalizedString>
 #include <KMessageBox>
 
-#include <QFileInfo>
+#include <KFileUtils>
 #include <QDir>
+#include <QFileInfo>
 #include <QMimeDatabase>
-#include <QTimer>
 #include <QPointer>
+#include <QTimer>
 
 namespace Kerfuffle
 {
@@ -70,7 +71,7 @@ bool AddToArchive::showAddDialog()
     qCDebug(ARK) << "Opening add dialog";
 
     if (m_filename.isEmpty()) {
-        m_filename = detectBaseName(m_entries);
+        m_filename = getFileNameForEntries(m_entries, QString());
     }
 
     QPointer<Kerfuffle::CreateDialog> dialog = new Kerfuffle::CreateDialog(
@@ -169,6 +170,9 @@ void AddToArchive::slotStartJob()
 
     m_createJob = Archive::create(m_filename, m_mimeType, m_entries, m_options, this);
 
+    m_createJob->setProperty("immediateProgressReporting", m_immediateProgressReporting);
+    m_createJob->setProperty("destUrl", QUrl::fromLocalFile(m_filename));
+
     if (!m_password.isEmpty()) {
         m_createJob->enableEncryption(m_password, m_enableHeaderEncryption);
     }
@@ -180,18 +184,8 @@ void AddToArchive::slotStartJob()
 
 void AddToArchive::detectFileName()
 {
-    const QString base = detectBaseName(m_entries);
-    const QString suffix = !m_autoFilenameSuffix.isEmpty() ? QLatin1Char( '.' ) + m_autoFilenameSuffix : QString();
-
-    QString finalName = base + suffix;
-
-    //if file already exists, append a number to the base until it doesn't
-    //exist
-    int appendNumber = 0;
-    while (QFileInfo::exists(finalName)) {
-        ++appendNumber;
-        finalName = base + QLatin1Char( '_' ) + QString::number(appendNumber) + suffix;
-    }
+    const QString suffix = !m_autoFilenameSuffix.isEmpty() ? m_autoFilenameSuffix : QString();
+    const QString finalName = getFileNameForEntries(m_entries, suffix);
 
     qCDebug(ARK) << "Autoset filename to" << finalName;
     m_filename = finalName;
@@ -208,23 +202,47 @@ void AddToArchive::slotFinished(KJob *job)
     emitResult();
 }
 
-QString AddToArchive::detectBaseName(const QVector<Archive::Entry*> &entries) const
+QString findCommonPrefixForUrls(const QList<QUrl> &list)
 {
-    QFileInfo fileInfo = QFileInfo(entries.first()->fullPath());
-    QDir parentDir = fileInfo.dir();
-    QString base = parentDir.absolutePath() + QLatin1Char('/');
+    Q_ASSERT(!list.isEmpty());
+    QString prefix = list.front().fileName();
+    for (QList<QUrl>::const_iterator it = list.begin(); it != list.end(); ++it) {
+        const auto fileName = it->fileName();
+        if (prefix.length() > fileName.length()) {
+            prefix.truncate(fileName.length());
+        }
 
-    if (entries.size() > 1) {
-        if (!parentDir.isRoot()) {
-            // Use directory name for the new archive.
-            base += parentDir.dirName();
+        for (int i = 0; i < prefix.length(); ++i) {
+            if (prefix.at(i) != fileName.at(i)) {
+                prefix.truncate(i);
+                break;
+            }
+        }
+    }
+
+    return prefix;
+}
+
+QString AddToArchive::getFileNameForUrls(const QList<QUrl> &urls, const QString &suffix)
+{
+    Q_ASSERT(!urls.isEmpty());
+
+    const QFileInfo fileInfo = QFileInfo(urls.constFirst().toLocalFile());
+    QString base;
+
+    if (urls.size() > 1) {
+        QString prefix = findCommonPrefixForUrls(urls);
+        if (prefix.length() < 5) {
+            base = i18nc("Default name of a newly-created multi-file archive", "Archive");
+        } else {
+            base = prefix;
         }
     } else {
         // Strip filename of its extension, but only if present (see #362690).
         if (!QMimeDatabase().mimeTypeForFile(fileInfo.fileName(), QMimeDatabase::MatchExtension).isDefault()) {
-            base += fileInfo.completeBaseName();
+            base = fileInfo.completeBaseName();
         } else {
-            base += fileInfo.fileName();
+            base = fileInfo.fileName();
         }
     }
 
@@ -233,11 +251,31 @@ QString AddToArchive::detectBaseName(const QVector<Archive::Entry*> &entries) co
         base.chop(4);
     }
 
-    if (base.endsWith(QLatin1Char('/'))) {
-        base.chop(1);
+    QString finalName = base + QLatin1Char('.') + suffix;
+
+    // if file already exists, append a number to the base until it doesn't
+    // exist
+    int appendNumber = 0;
+    const QString path = fileInfo.absolutePath() + QStringLiteral("/");
+    while (QFileInfo::exists(path + finalName)) {
+        ++appendNumber;
+        finalName = KFileUtils::makeSuggestedName(finalName);
     }
 
-    return base;
+    return path + finalName;
 }
 
+QString AddToArchive::getFileNameForEntries(const QVector<Archive::Entry *> &entries, const QString &suffix)
+{
+    QList<QUrl> urls;
+    for (const auto &entry : entries) {
+        urls.append(QUrl::fromLocalFile(entry->fullPath()));
+    }
+    return getFileNameForUrls(urls, suffix);
+}
+
+void AddToArchive::setImmediateProgressReporting(bool immediateProgressReporting)
+{
+    m_immediateProgressReporting = immediateProgressReporting;
+}
 }
